@@ -3,6 +3,7 @@ import io
 import json
 import logging
 from contextlib import contextmanager
+from typing import Tuple
 
 DEFAULT_DATABASE = "locators.json"
 
@@ -34,6 +35,26 @@ def open_stream(obj, *args, **kwargs):
             obj.close()
 
 
+def load_by_name(path, name) -> Tuple[str, dict]:
+    db = LocatorsDatabase(path)
+    if not os.path.exists(db.path):
+        db.logger.warning("File does not exist: %s", db.path)
+
+    db.load()
+    if db.error:
+        error_msg, error_args = db.error
+        raise ValidationError(error_msg % error_args)
+
+    entry = db.find_by_name(name)
+    if not entry:
+        raise ValueError(f"Unknown locator alias: {name}")
+
+    locator = "{prefix}:{name}".format(prefix=entry["strategy"], name=entry["value"])
+
+    db.logger.info("%s is an alias for %s", name, locator)
+    return locator, entry
+
+
 class ValidationError(ValueError):
     """Validation error from malformed database or locator entry."""
 
